==> SeqUtils-1.0.4.tar.gz: SeqUtils-1.0.4/sequtils/email_alerts.py <==
#! /usr/local/bin/python
# from smtplib import SMTP_SSL as SMTP       # this invokes the secure SMTP protocol (port 465, uses SSL)
from smtplib import SMTP_SSL, SMTP       # this invokes the secure SMTP protocol (port 465, uses SSL)
from email.mime.text import MIMEText
try:
    from . import auth
except:
    import auth

def send(**kwargs):
    if('auth' in kwargs):
        params = kwargs['auth']
    else:
        print("Auth not specified. Trying to load auth")
        params = auth.load_default_auth()
    SMTPserver = params['SMTPserver']
    USERNAME = params['USERNAME']
    if('PASSWORD' in params): 
        PASSWORD = params['PASSWORD']
    else:
        print("[Warning!] No password specified!")
        PASSWORD = ''
    #fail sender to username if not provided
    if('sender' in params): sender = params['sender']
    else: sender = params['USERNAME']
    text_subtype = 'plain'

    #compose message
    if('destination' in kwargs):
        destination =kwargs['destination']
    elif('to' in kwargs):
        destination = kwargs['to']
    elif('destination' in params):
        print("Trying to load destination from file")
        destination = params['destination']
    elif('to' in params):
        print("Trying to load destination from file")
        destination = params['to']
    else:
        print("No destination specified. Using sender address")
        destination = sender
    if('subject' in kwargs):
        subject=kwargs['subject']
    else:
        subject = "Message from: "+sender
    if('message' in kwargs):
        content=kwargs['message']
    else:
        content = subject
    msg = MIMEText(content, text_subtype)
    msg['Subject']= subject
    msg['From']   = sender # some SMTP servers will do this automatically, not all

    try:
        conn = SMTP_SSL(SMTPserver)
        conn.set_debuglevel(False)
        conn.login(USERNAME, PASSWORD)
    except:
        print("Unable to authenticate with secure SMTP with SSL. Trying SMTP.")
        conn = SMTP(SMTPserver)
        conn.set_debuglevel(False)
        conn.login(USERNAME, PASSWORD)
    try:
        conn.sendmail(sender, destination, msg.as_string())
    except:
        raise Exception("[Error] Unable to send message")
    finally:
        conn.quit()
    return True

==> SeqUtils-1.0.10.tar.gz: SeqUtils-1.0.10/sequtils/email_alerts.py <==
#! /usr/local/bin/python
# from smtplib import SMTP_SSL as SMTP       # this invokes the secure SMTP protocol (port 465, uses SSL)
from smtplib import SMTP_SSL, SMTP       # this invokes the secure SMTP protocol (port 465, uses SSL)
from email.mime.text import MIMEText
# try:
#     from . import auth
# except:
#     try:
#         import auth
#     except:
#         print("Failed to import auth")

def send(*args,**kwargs):
    if('auth' in kwargs):
        params = kwargs['auth']
    else:
        params = args[0]
    SMTPserver = params['SMTPserver']
    USERNAME = params['USERNAME']
    if('PASSWORD' in params): 
        PASSWORD = params['PASSWORD']
    else:
        print("[Warning!] No password specified!")
        PASSWORD = None
    #fail sender to username if not provided
    if('sender' in params): sender = params['sender']
    else: sender = params['USERNAME']
    if('type' in kwargs):
        text_subtype = kwargs['type']
    else:
        text_subtype = 'plain'

    #compose message
    if('destination' in kwargs):
        destination =kwargs['destination']
    elif('to' in kwargs):
        destination = kwargs['to']
    elif('destination' in params):
        print("Trying to load destination from file")
        destination = params['destination']
    elif('to' in params):
        print("Trying to load destination from file")
        destination = params['to']
    else:
        print("No destination specified. Using sender address")
        destination = sender
    if('subject' in kwargs):
        subject=kwargs['subject']
    else:
        subject = "Message from: "+sender
    if('message' in kwargs):
        content=kwargs['message']
    else:
        content = subject
    msg = MIMEText(content, text_subtype)
    msg['Subject']= subject
    msg['From']   = sender # some SMTP servers will do this automatically, not all

    if(PASSWORD):
        try:
            conn = SMTP_SSL(SMTPserver)
            # conn.set_debuglevel(False)
            conn.login(USERNAME, PASSWORD)
        except:
            print("Unable to authenticate with secure SMTP with SSL. Trying SMTP.")
            try:
                conn = SMTP(SMTPserver)
                conn.login(USERNAME, PASSWORD)
            except:
                conn = SMTP(SMTPserver)
    else:
        print("Trying without authenticating.")
        conn = SMTP(SMTPserver)
    try:
        print("Sending message")
        conn.sendmail(sender, destination, msg.as_string())
    except:
        raise Exception("[Error] Unable to send message")
    finally:
        conn.quit()
    return True
